==> getml-1.2.0.tar.gz: getml-1.2.0/setup.py <==
# Copyright 2019 The SQLNet Company GmbH

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

"""setup.py for getml"""

from setuptools import find_packages, setup

exec(open("getml/version.py").read())

long_description = """
    getML (https://getml.com) is a software for automated machine learning
    (AutoML) with a special focus on feature learning for relational data
    and time series. The getML algorithms can produce features that are far
    more advanced than what any data scientist could write by hand or what you
    could accomplish using simple brute force approaches.

    This is the official python client for the getML engine.

    Documentation and more details at https://docs.getml.com/{}
""".format(
    __version__
)


setup(
    name="getml",
    version=__version__,
    author="getML",
    author_email="support@getml.com",
    url="https://docs.getml.com/" + __version__,
    download_url="https://github.com/getml/getml-python-api",
    description="Python API for getML",
    long_description=long_description,
    packages=find_packages(),
    package_data={"getml": ["utilities/templates/*.jinja2"]},
    install_requires=[
        "pandas",
        "pyarrow>=5.0,<5.1",
        "numpy>=1.22",
        "jinja2",
        "scipy",
    ],
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
    keywords=["AutoML", "feature learning"],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Financial and Insurance Industry",
        "Intended Audience :: Telecommunications Industry",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Manufacturing",
        "Intended Audience :: Healthcare Industry",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

==> getml-1.3.0.tar.gz: getml-1.3.0/setup.py <==
# Copyright 2022 The SQLNet Company GmbH
# 
# This file is licensed under the Elastic License 2.0 (ELv2). 
# Refer to the LICENSE.txt file in the root of the repository 
# for details.
# 

"""setup.py for getml"""

from setuptools import find_packages, setup

exec(open("getml/version.py").read())

long_description = """
    getML (https://getml.com) is a software for automated machine learning
    (AutoML) with a special focus on feature learning for relational data
    and time series.

    This is the official python client for the getML engine.

    Documentation and more details at https://docs.getml.com/{}
""".format(
    __version__
)


setup(
    name="getml",
    version=__version__,
    author="getML",
    author_email="support@getml.com",
    url="https://docs.getml.com/" + __version__,
    download_url="https://github.com/getml/getml-python-api",
    description="Python API for getML",
    long_description=long_description,
    packages=find_packages(),
    package_data={"getml": ["py.typed", "utilities/templates/*.jinja2"]},
    install_requires=[
        "pandas",
        "pyarrow>=7.0,<7.1",
        "numpy>=1.22",
        "jinja2",
        "scipy",
    ],
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
    keywords=["AutoML", "feature learning"],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Financial and Insurance Industry",
        "Intended Audience :: Telecommunications Industry",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Manufacturing",
        "Intended Audience :: Healthcare Industry",
        "Operating System :: OS Independent",
    ],
)
